@@ -1,7 +1,10 @@
 import dataclasses
 import re
+from datetime import timedelta
 from typing import Callable, List, Mapping, Optional, TypeVar
 
+import click
+
 from .formatters.ftable import Align, ColumnWidth
 
 
@@ -21,7 +24,7 @@ def parse_memory(memory: str) -> int:
     if not memory:
         raise value_error
 
-    pattern = r"^(?P<value>\d+)(?P<units>(kB|K)|((?P<prefix>[{prefixes}])(?P<unit>B?)))$".format(  # NOQA
+    pattern = r"^(?P<value>\d+)(?P<units>(kB|kb|K|k)|((?P<prefix>[{prefixes}])(?P<unit>[bB]?)))$".format(  # NOQA
         prefixes=prefixes
     )
     regex = re.compile(pattern)
@@ -37,10 +40,10 @@ def parse_memory(memory: str) -> int:
     prefix = groups["prefix"]
     units = groups["units"]
 
-    if units == "kB":
+    if units == "kB" or units == "kb":
         return value * 1000
 
-    if units == "K":
+    if units == "K" or units == "k":
         return value * 1024
 
     # Our prefix string starts with Mega
@@ -213,3 +216,28 @@ def parse_columns(fmt: Optional[str]) -> List[JobColumnInfo]:
     if not ret:
         raise ValueError(f"Invalid format {fmt!r}")
     return ret
+
+
+REGEX_TIME_DELTA = re.compile(
+    r"^((?P<d>\d+)d)?((?P<h>\d+)h)?((?P<m>\d+)m)?((?P<s>\d+)s)?$"
+)
+
+
+def parse_timedelta(value: str) -> timedelta:
+    value = value.strip()
+    err = f"Could not parse time delta '{value}'"
+    if value == "":
+        raise click.UsageError(f"{err}: Empty string not allowed")
+    if value == "0":
+        return timedelta(0)
+    match = REGEX_TIME_DELTA.search(value)
+    if match is None:
+        raise click.UsageError(
+            f"{err}: Should be like '1d2h3m4s' (some parts may be missing)."
+        )
+    return timedelta(
+        days=int(match.group("d") or 0),
+        hours=int(match.group("h") or 0),
+        minutes=int(match.group("m") or 0),
+        seconds=int(match.group("s") or 0),
+    )
