@@ -47,10 +47,12 @@ async def add(root: Root, key: str, value: str) -> None:
 @argument("key")
 async def rm(root: Root, key: str) -> None:
     """
-    Add secret KEY.
+    Remove secret KEY.
     """
 
     await root.client.secrets.rm(key)
+    if root.verbosity > 0:
+        click.echo(f"Secret with key '{key}' was successfully removed")
 
 
 secret.add_command(ls)
