@@ -9,6 +9,8 @@ import re
 import shlex
 import shutil
 import sys
+import warnings
+from datetime import timedelta
 from typing import (
     Any,
     Awaitable,
@@ -35,6 +37,7 @@ from yarl import URL
 from neuromation.api import Action, Client, Factory, JobStatus, TagOption, Volume
 from neuromation.api.url_utils import uri_from_cli
 
+from .parse_utils import parse_timedelta
 from .root import Root
 from .stats import upload_gmp_stats
 from .version_utils import run_version_checker
@@ -94,7 +97,8 @@ async def _run_async_function(
 
 
 def _wrap_async_callback(
-    callback: Callable[..., Awaitable[_T]], init_client: bool = True,
+    callback: Callable[..., Awaitable[_T]],
+    init_client: bool = True,
 ) -> Callable[..., _T]:
     assert inspect.iscoroutinefunction(callback)
 
@@ -260,7 +264,8 @@ class Command(NeuroClickMixin, click.Command):
         if wrap_async:
             callback = _wrap_async_callback(callback, init_client=init_client)
         super().__init__(
-            callback=callback, **kwargs,
+            callback=callback,
+            **kwargs,
         )
         self.init_client = init_client
 
@@ -473,7 +478,7 @@ SHARE_SCHEMES = ("storage", "image", "job", "blob", "role")
 
 
 def parse_resource_for_sharing(uri: str, root: Root) -> URL:
-    """ Parses the neuromation resource URI string.
+    """Parses the neuromation resource URI string.
     Available schemes: storage, image, job. For image URIs, tags are not allowed.
     """
     if uri.startswith("image:"):
@@ -493,7 +498,7 @@ def parse_resource_for_sharing(uri: str, root: Root) -> URL:
 
 
 def parse_file_resource(uri: str, root: Root) -> URL:
-    """ Parses the neuromation resource URI string.
+    """Parses the neuromation resource URI string.
     Available schemes: file, storage.
     """
     return uri_from_cli(
@@ -523,7 +528,10 @@ def parse_blob_or_file_resource(uri: str, root: Root) -> URL:
 
 def parse_secret_resource(uri: str, root: Root) -> URL:
     return uri_from_cli(
-        uri, root.client.username, root.client.cluster_name, allowed_schemes=("secret"),
+        uri,
+        root.client.username,
+        root.client.cluster_name,
+        allowed_schemes=("secret"),
     )
 
 
@@ -618,3 +626,35 @@ def steal_config_maybe(dst_path: pathlib.Path) -> None:
             os.chmod(target, 0o600)
             f.unlink()
         src.rmdir()
+
+
+async def calc_life_span(
+    client: Client, value: Optional[str], default: str, config_section: str
+) -> Optional[float]:
+    async def _calc_default_life_span(client: Client) -> timedelta:
+        config = await client.config.get_user_config()
+        section = config.get(config_section)
+        life_span = default
+        if section is not None:
+            value = section.get("life-span")
+            if value is not None:
+                life_span = value
+        return parse_timedelta(life_span)
+
+    delta = (
+        parse_timedelta(value)
+        if value is not None
+        else await _calc_default_life_span(client)
+    )
+    seconds = delta.total_seconds()
+    if seconds == 0:
+        warnings.warn(
+            "Zero job's life-span (--life-span=0) is deprecated "
+            "and will be removed in the future neuro CLI release,"
+            "use a positive value to avoid resource leakage",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        return None
+    assert seconds > 0
+    return seconds
