@@ -1,5 +1,4 @@
 import logging
-from datetime import timedelta
 from pathlib import Path
 from typing import Any, Callable, Tuple
 
@@ -9,17 +8,7 @@ import toml
 from yarl import URL
 
 from neuromation.api import Client, JobStatus
-from neuromation.cli.job import (
-    DEFAULT_JOB_LIFE_SPAN,
-    NEUROMATION_ROOT_ENV_VAR,
-    _extract_secret_env,
-    _parse_cmd,
-    _parse_timedelta,
-    build_env,
-    calc_columns,
-    calc_life_span,
-    calc_statuses,
-)
+from neuromation.cli.job import _parse_cmd, calc_columns, calc_statuses
 from neuromation.cli.parse_utils import COLUMNS_MAP, get_default_columns
 from neuromation.cli.root import Root
 
@@ -113,54 +102,83 @@ def test_calc_statuses__check_defaults__all_statuses_true(
     assert not caplog.text
 
 
-@pytest.mark.parametrize(
-    "env_var", [NEUROMATION_ROOT_ENV_VAR, f"{NEUROMATION_ROOT_ENV_VAR}=value"]
-)
-def test_build_env_reserved_env_var_conflict_passed_as_parameter(env_var: str) -> None:
-    env = ("ENV_VAR_1=value", "ENV_VAR_2=value", env_var)
-    with pytest.raises(
-        click.UsageError,
-        match="Unable to re-define system-reserved environment variable",
-    ):
-        build_env(env, env_file=None)
-
-
-@pytest.mark.parametrize(
-    "env_var", [NEUROMATION_ROOT_ENV_VAR, f"{NEUROMATION_ROOT_ENV_VAR}=value"]
-)
-def test_build_env_reserved_env_var_conflict_passed_in_file(
-    env_var: str, tmp_path: Path
-) -> None:
-    env_1 = ("ENV_VAR_1=value",)
-    env_2 = ("ENV_VAR_2=value", env_var)
-    env_file = tmp_path / "env_var.txt"
-    env_file.write_text("\n".join(env_2))
-
-    with pytest.raises(
-        click.UsageError,
-        match="Unable to re-define system-reserved environment variable",
-    ):
-        build_env(env_1, env_file=str(env_file))
-
-
-def test_build_env_blank_lines(tmp_path: Path) -> None:
+def test_build_env_blank_lines(tmp_path: Path, root: Root) -> None:
     env_file = tmp_path / "env_var.txt"
     env_file.write_text("ENV_VAR_1=value1\n\n  \n\t\nENV_VAR_2=value2")
-    assert build_env([], env_file=str(env_file)) == {
+    assert root.client.parse._build_env([], [str(env_file)]) == {
         "ENV_VAR_1": "value1",
         "ENV_VAR_2": "value2",
     }
 
 
-def test_build_env_comments(tmp_path: Path) -> None:
+def test_build_env_comments(tmp_path: Path, root: Root) -> None:
     env_file = tmp_path / "env_var.txt"
     env_file.write_text("ENV_VAR_1=value1\n#ENV_VAR_2=value2\nENV_VAR_3=#value3#")
-    assert build_env([], env_file=str(env_file)) == {
+    assert root.client.parse._build_env([], [str(env_file)]) == {
         "ENV_VAR_1": "value1",
         "ENV_VAR_3": "#value3#",
     }
 
 
+def test_build_env_multiple_files(tmp_path: Path, root: Root) -> None:
+    env_1 = ("ENV_VAR_1=value1",)
+    env_2 = ("ENV_VAR_2=value2",)
+    env_file1 = tmp_path / "env_var.txt"
+    env_file1.write_text("\n".join(env_1))
+    env_file2 = tmp_path / "env_var2.txt"
+    env_file2.write_text("\n".join(env_2))
+
+    assert root.client.parse._build_env([], [str(env_file1), str(env_file2)]) == {
+        "ENV_VAR_1": "value1",
+        "ENV_VAR_2": "value2",
+    }
+
+
+def test_build_env_override_literals(root: Root) -> None:
+    env = ("ENV_VAR=value1", "ENV_VAR=value2")
+
+    assert root.client.parse._build_env(env) == {
+        "ENV_VAR": "value2",
+    }
+
+
+def test_build_env_override_literal_and_file(tmp_path: Path, root: Root) -> None:
+    env_1 = ("ENV_VAR=value1",)
+    env_2 = ("ENV_VAR=value2",)
+    env_file = tmp_path / "env_var.txt"
+    env_file.write_text("\n".join(env_2))
+
+    assert root.client.parse._build_env(env_1, [str(env_file)]) == {
+        "ENV_VAR": "value1",
+    }
+
+
+def test_build_env_override_same_file(tmp_path: Path, root: Root) -> None:
+    env = (
+        "ENV_VAR=value1",
+        "ENV_VAR=value2",
+    )
+    env_file = tmp_path / "env_var.txt"
+    env_file.write_text("\n".join(env))
+
+    assert root.client.parse._build_env([], [str(env_file)]) == {
+        "ENV_VAR": "value2",
+    }
+
+
+def test_build_env_override_different_files(tmp_path: Path, root: Root) -> None:
+    env_1 = ("ENV_VAR=value1",)
+    env_2 = ("ENV_VAR=value2",)
+    env_file1 = tmp_path / "env_var.txt"
+    env_file1.write_text("\n".join(env_1))
+    env_file2 = tmp_path / "env_var2.txt"
+    env_file2.write_text("\n".join(env_2))
+
+    assert root.client.parse._build_env([], [str(env_file1), str(env_file2)]) == {
+        "ENV_VAR": "value2",
+    }
+
+
 def test_extract_secret_env(root: Root) -> None:
     username = root.client.username
     cluster_name = root.client.cluster_name
@@ -171,7 +189,7 @@ def test_extract_secret_env(root: Root) -> None:
         "ENV_VAR_4": "value4",
         "ENV_VAR_5": "secret://othercluster/otheruser/value5",
     }
-    assert _extract_secret_env(env, root) == {
+    assert root.client.parse._extract_secret_env(env) == {
         "ENV_VAR_1": URL(f"secret://{cluster_name}/{username}/value1"),
         "ENV_VAR_3": URL(f"secret://{cluster_name}/otheruser/value3"),
         "ENV_VAR_5": URL(f"secret://othercluster/otheruser/value5"),
@@ -206,105 +224,6 @@ async def test_calc_columns_user_spec(
         ]
 
 
-async def test_calc_life_span_none_default(
-    monkeypatch: Any, tmp_path: Path, make_client: _MakeClient
-) -> None:
-    async with make_client("https://example.com") as client:
-        monkeypatch.chdir(tmp_path)
-        local_conf = tmp_path / ".neuro.toml"
-        local_conf.write_text(toml.dumps({"job": {"life-span": "1d2h3m4s"}}))
-        expected = timedelta(days=1, hours=2, minutes=3, seconds=4)
-        assert await calc_life_span(client, None) == expected.total_seconds()
-
-
-async def test_calc_life_span_zero(make_client: _MakeClient) -> None:
-    async with make_client("https://example.com") as client:
-        assert await calc_life_span(client, "0") is None
-
-
-async def test_calc_life_span_default_life_span_all_keys(
-    caplog: Any, monkeypatch: Any, tmp_path: Path, make_client: _MakeClient
-) -> None:
-    async with make_client("https://example.com") as client:
-        monkeypatch.chdir(tmp_path)
-        local_conf = tmp_path / ".neuro.toml"
-        # empty config
-        local_conf.write_text(toml.dumps({"job": {"life-span": "1d2h3m4s"}}))
-
-        expected = timedelta(days=1, hours=2, minutes=3, seconds=4)
-        assert await calc_life_span(client, None) == expected.total_seconds()
-
-
-async def test_calc_default_life_span_invalid(
-    caplog: Any, monkeypatch: Any, tmp_path: Path, make_client: _MakeClient,
-) -> None:
-    async with make_client("https://example.com") as client:
-        monkeypatch.chdir(tmp_path)
-        local_conf = tmp_path / ".neuro.toml"
-        # empty config
-        local_conf.write_text(toml.dumps({"job": {"life-span": "invalid"}}))
-        with pytest.raises(
-            click.UsageError, match="Could not parse time delta",
-        ):
-            await calc_life_span(client, None)
-
-
-async def test_calc_default_life_span_default_value(
-    caplog: Any, monkeypatch: Any, tmp_path: Path, make_client: _MakeClient,
-) -> None:
-    async with make_client("https://example.com") as client:
-        monkeypatch.chdir(tmp_path)
-        local_conf = tmp_path / ".neuro.toml"
-        # empty config
-        local_conf.write_text(toml.dumps({}))
-        default = _parse_timedelta(DEFAULT_JOB_LIFE_SPAN)
-        assert await calc_life_span(client, None) == default.total_seconds()
-
-
-def test_parse_timedelta_valid_zero() -> None:
-    assert _parse_timedelta("0") == timedelta(0)
-
-
-def test_parse_timedelta_valid_all_groups_no_spaces() -> None:
-    expected = timedelta(days=1, hours=2, minutes=3, seconds=4)
-    assert _parse_timedelta("1d2h3m4s") == expected
-
-
-def test_parse_timedelta_valid_all_groups_spaces_around() -> None:
-    expected = timedelta(days=1, hours=2, minutes=3, seconds=4)
-    assert _parse_timedelta("  1d2h3m4s ") == expected
-
-
-def test_parse_timedelta_valid_some_groups_1() -> None:
-    expected = timedelta(days=1, hours=2, seconds=4)
-    assert _parse_timedelta("1d2h4s") == expected
-
-
-def test_parse_timedelta_valid_some_groups_2() -> None:
-    expected = timedelta(days=1, hours=1)
-    assert _parse_timedelta("1d1h") == expected
-
-
-def test_parse_timedelta_valid_some_groups_3() -> None:
-    expected = timedelta(days=1)
-    assert _parse_timedelta("1d") == expected
-
-
-def test_parse_timedelta_invalid_empty() -> None:
-    with pytest.raises(click.UsageError, match="Empty string not allowed"):
-        _parse_timedelta("")
-
-
-def test_parse_timedelta_invalid() -> None:
-    with pytest.raises(click.UsageError, match="Should be like"):
-        _parse_timedelta("invalid")
-
-
-def test_parse_timedelta_invalid_negative() -> None:
-    with pytest.raises(click.UsageError, match="Should be like"):
-        _parse_timedelta("-1d")
-
-
 def test_parse_cmd_single() -> None:
     cmd = ["bash -c 'ls -l && pwd'"]
     assert _parse_cmd(cmd) == "bash -c 'ls -l && pwd'"
